==> fwobac-1.2.tar.gz: fwobac-1.2/base64.h <==
/* $Id: base64.h,v 1.3 2017/08/05 11:39:22 rlr Exp $ */

/*
 * Copyright (c) 2016 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _BASE64_H_
#define _BASE64_H_


#include <stddef.h>


/*
 * Base64-encodes the given data into the given string buffer.  Returns the
 * length of the output string (excluding terminating NUL) or -1 on error.
 */
int	 base64_encode(const void *, size_t, char *, size_t);

/*
 * Base64-decodes the given string into the supplied buffer.  Returns the
 * length of the output (in octets) or -1 on error.
 */
int	 base64_decode(const char *src, void *dst, size_t dst_sz);

/*
 * Returns non-zero if and only if the given string (which must be non-NULL)
 * is non-empty and valid Base64-encoded data.
 */
int	 base64_is_well_formed(const char *);

/*
 * Returns the length (in octets) to which the given Base64-encoded string
 * would decode.  The string must be (non-NULL, non-empty) valid Base64.
 */
size_t	 base64_decoded_length(const char *);

#endif /* !_BASE64_H_ */

==> fwobac-1.6.tar.gz: fwobac-1.6/base64.h <==
/* $Id: base64.h,v 1.7 2018/06/19 04:39:06 rlr Exp $ */

/*
 * Copyright (c) 2016, 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _BASE64_H_
#define _BASE64_H_


#include <stddef.h>


/*
 * int
 * base64_encode(const void *src, size_t src_sz, char *dst, size_t dst_sz);
 *
 * Base64-encodes the given data into the given string buffer.  Returns the
 * length of the output string (excluding terminating NUL) or -1 on error.
 */
int	 base64_encode(const void *, size_t, char *, size_t);


/*
 * int
 * base64_decode(const char *src, void *dst, size_t dst_sz);
 *
 * Base64-decodes the given string into the supplied buffer.  Returns the
 * length of the output (in octets) or -1 on error.
 */
int	 base64_decode(const char *, void *, size_t);


/*
 * int
 * base64_is_well_formed(const char *e);
 *
 * Returns non-zero if and only if string e (which must be non-NULL) is
 * non-empty and valid Base64-encoded data.
 */
int	 base64_is_well_formed(const char *);


/*
 * size_t
 * base64_decoded_length(const char *e);
 *
 * Returns the length (in octets) to which the Base64-encoded string e
 * would decode.  The string must be (non-NULL, non-empty) valid Base64.
 */
size_t	 base64_decoded_length(const char *);


#endif /* !_BASE64_H_ */
